from abc import ABC, abstractmethod
from typing import List, Dict

import requests


class AsrProcessor(ABC):

    @abstractmethod
    def call_recognise(self, file_path: str) -> List[Dict[str, any]]:
        """
        Currently most important is field `transcript` with list of transcript
        words.
        """
        pass


class AsrWebClient(AsrProcessor):
    _url: str

    def __init__(self, url: str):
        super(AsrWebClient, self).__init__()
        self._url = url

    def call_recognise(self, file_path: str) -> List[Dict[str, any]]:
        files = {'file': open(file_path, 'rb')}
        res = requests.post(self._url, files=files)
        json_response = res.json()
        print(json_response)
        return json_response
